Expyrimenter
============

.. image:: https://readthedocs.org/projects/expyrimenter/badge/?version=latest
.. image:: https://travis-ci.org/cemsbr/expyrimenter.svg?branch=master
.. image:: https://coveralls.io/repos/cemsbr/expyrimenter/badge.png

Python tool to help experiment automation.
It helps to execute local and remote commands in parallel.
A quick example and documentation are available at `Read the Docs
<http://expyrimenter.rtfd.org/en/latest/>`_.
